package router

import (
	"github.com/gin-gonic/gin"
	jwt "github.com/go-admin-team/go-admin-core/sdk/pkg/jwtauth"
	"go-admin/app/admin/apis/bus_apis"
	"go-admin/common/middleware"
)

// 需认证的路由代码
func registerSmsManageRouter(v1 *gin.RouterGroup, authMiddleware *jwt.GinJWTMiddleware) {
	api := bus_apis.SmsApi{}

	sms := v1.Group("/sms").Use(authMiddleware.MiddlewareFunc()).Use(middleware.AuthCheckRole())
	{

		sms.POST("/self_import_phone", api.SelfImportPhone)   // 导入号码（个性短信）
		sms.POST("/file_import_phone", api.FileImportPhone)   // 导入号码（文件短信）
		sms.POST("/excel_import_phone", api.ExcelImportPhone) // 导入号码（EXCEL短信）

		sms.POST("/mass_import_phone", api.MassImportPhone) // 导入号码（群发短信）
		sms.POST("/export_mess_phone", api.ExportMessPhone) // 导出号码（群发短信）

		sms.POST("/check_sensitive_words", api.CheckSensitiveWords) // 敏感词检测
		sms.POST("/send_sms", api.SendSms)                          // 提交发送任务

		sms.POST("/sms_log", api.QuerySmsTaskList)         // 查询短信下行记录 OK
		sms.POST("/sms_phone_log", api.SmsSendRecordQuery) // 查询短信下行明细 OK
		sms.POST("/get_phones", api.GetPhonesByBatchID)    // 根据批次ID获取手机号
		sms.POST("/uplink_log", api.QuerySmsUplinkList)    // 查询短信上行记录 OK

		sms.POST("/sms_timing_list", api.QueryScheduledSmsTaskList)           // 查询短信定时记录 OK
		sms.POST("/batch_update_content", api.BatchUpdateScheduledSmsContent) // 批量修改定时短信内容
		sms.POST("/batch_cancel", api.BatchCancelScheduledSms)                // 批量取消定时短信任务
		sms.POST("/batch_reset_schedule", api.BatchResetScheduledSms)         // 批量重置定时发送时间

		sms.POST("/signature_realname/list", api.ListSignatureRealname)     // 查询签名实名制列表 OK
		sms.POST("/signature_realname/create", api.CreateSignatureRealname) // 新增实名签名
		sms.POST("/signature_realname/update", api.UpdateSignatureRealname) // 编辑实名签名
		sms.POST("/signature_realname/delete", api.DeleteSignatureRealname) // 批量删除签名实名记录

		sms.POST("/contacts_category/add", api.AddContactsCategory)         // 新增通讯录分类节点
		sms.POST("/contacts_category/edit", api.EditContactsCategory)       // 编辑通讯录分类节点
		sms.POST("/contacts_category/delete", api.DeleteContactsCategories) // 删除通讯录分类
		sms.POST("/contacts_category/list", api.ListContactsCategories)     // 查询通讯录分类列表（树形结构） OK
		sms.POST("/contacts/list", api.ListContacts)                        // 查询通讯录列表 OK
		sms.POST("/contacts/add", api.AddContact)                           // 新增联系人
		sms.POST("/contacts/edit", api.EditContact)                         // 编辑联系人
		sms.POST("/contacts/batch_delete", api.BulkDeleteContacts)          // 批量删除联系人
		sms.POST("/contacts/import", api.BulkImportContacts)                // 批量导入通讯录
		sms.POST("/contacts/export", api.BulkExportContacts)                // 批量导出通讯录 OK

		sms.POST("/phrase_category/add", api.AddPhraseCategory)         // 新增短语分类节点
		sms.POST("/phrase_category/edit", api.EditPhraseCategory)       // 编辑短语分类节点
		sms.POST("/phrase_category/delete", api.DeletePhraseCategories) // 删除常用短语分类
		sms.POST("/phrase_category/list", api.ListPhraseCategories)     // 查询常用短语分类列表（树形结构） OK
		sms.POST("/phrase/add", api.AddPhrase)                          // 新增常用短语
		sms.POST("/phrase/edit", api.EditPhrase)                        // 编辑常用短语
		sms.POST("/phrase/delete", api.DeletePhrases)                   // 批量删除短语
		sms.POST("/phrase/list", api.ListPhrases)                       // 查询常用短语列表 OK

		sms.POST("/common_number/list", api.ListCommonNumbers)     // 常用号码列表 OK
		sms.POST("/common_number/add", api.AddCommonNumber)        // 添加常用号码
		sms.POST("/common_number/append", api.AppendCommonNumber)  // 追加号码
		sms.POST("/common_number/detail", api.CommonNumberDetail)  // 常用号码详情
		sms.POST("/common_number/delete", api.DeleteCommonNumbers) // 批量删除常用号码
		sms.POST("/common_number/export", api.ExportCommonNumber)  // 导出常用号码 OK

		sms.POST("/black_list/add", api.AddBlacklistNumber) // 添加黑名单
		sms.POST("/black_list/list", api.ListBlacklist)     // 黑名单列表
		sms.POST("/black_list/export", api.ExportBlacklist) // 导出黑名单号码
		sms.POST("/black_list/delete", api.DeleteBlacklist) // 批量删除黑名单

		sms.POST("/template/create", api.CreateSmsTemplate)   // 新增短信模版 OK
		sms.POST("/template/delete", api.DeleteSmsTemplates)  // 批量删除短信模版
		sms.POST("/template/update", api.UpdateSmsTemplate)   // 修改短信模版
		sms.POST("/template/approve", api.ApproveSmsTemplate) // 审核短信模版
		sms.POST("/template/list", api.ListSmsTemplates)      // 获取短信模版列表 OK
		sms.POST("/template/export", api.ExportSmsTemplate)   // 导出短信模版 OK
	}
}
